FormFieldItem class

Inheritance

Constructors

FormFieldItem({Key? key, required String label, required String mapKey, String? hint, TextInputAction? textInputAction, TextEditingController? controller, InputDecoration? decoration, TextStyle? style, TextInputType textInputType = TextInputType.text, bool required = false, bool enabled = true, bool obscureText = false, bool autofocus = false, bool autocorrect = false, bool readOnly = false, String? initialValue, int? maxLength, String? validator(String?)?, void onEditingComplete()?, void onFieldSubmitted(String)?, void onSaved(String?)?, List<TextInputFormatter>? inputFormatters, dynamic onTap()?, dynamic onChanged(String val)?})
Create a new FormFieldItem instance

Properties

autocorrect → bool
final
autofocus → bool
final
controller ↔ TextEditingController?
getter/setter pair
decoration ↔ InputDecoration?
getter/setter pair
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
initialValue → String?
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
final
mapKey → String
final
maxLength → int?
final
obscureText → bool
final
onChanged → dynamic Function(String val)?
final
onEditingComplete → void Function()?
final
onFieldSubmitted → void Function(String)?
final
onSaved → void Function(String?)?
final
onTap → dynamic Function()?
final
readOnly → bool
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
final
textInputAction → TextInputAction?
final
textInputType → TextInputType
final
validator → String? Function(String?)?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited