IFormFieldItem class abstract

Interface for form field items

This interface is used to create custom form field items.

Constructors

IFormFieldItem()

Properties

controller ↔ TextEditingController?
getter/setter pair
decoration ↔ InputDecoration?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hint ↔ String?
getter/setter pair
initialValue ↔ String?
getter/setter pair
label ↔ String
getter/setter pair
mapKey ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited